ipsec auto --status | grep interface
ipsec auto --status | grep "[.][.][.]"
ipsec auto --ready
ipsec auto --status | grep interface
ipsec auto --status | grep "[.][.][.]"
